"""
    dictionary with simulation info for benchmarks
"""

# Load modules
import os
from avaframe.in3Utils import fileHandlerUtils as fU


def fetchBenchParameters(testName):
    """ Collect simulation parameter info from standard tests """

    # set desired benchmark simulation info dictionary
    if testName == 'avaBowlNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1BL_null_dfa_0.15500'},
            'testName': 'avaBowlNullTest',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1BL',
                'Release Area': ['Rel_Example'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Release thickness [m]': [1],
                'Initial mass [kg]': '20196151.98',
                'Final mass [kg]': '20196151.98',
                'Entrained mass [kg]': '0.00',
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '190.1'},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1BL'},
            'Test Info': {'type': 'text', 'Test Info': 'This test uses a bowl-shaped geometry.'}}

    elif testName == 'avaFlatPlaneNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1FP_null_dfa_0.15500'},
            'testName': 'avaFlatPlaneNullTest',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1FP',
                'Release Area': ['Rel_Example'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Release thickness [m]': [1.0],
                'Initial mass [kg]': '20000000.',
                'Final mass [kg]': '20000000.',
                'Entrained mass [kg]': '0.00',
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '18.5'},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1FP'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs on a flat plane geometry.'}}

    elif testName == 'avaHelixNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1HX_null_dfa_0.15500'},
            'testName': 'avaHelixNullTest',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1HX',
                'Release Area': ['Rel_Example'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Release thickness [m]': [1],
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '20522418.00',
                'Final mass [kg]': '20522418.00',
                'Entrained mass [kg]': '0.00',
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '144.5'},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1HX'},
            'Test Info': {'type': 'text', 'Test Info': 'This test uses a helix-shaped geometry.'}}

    elif testName ==  'avaHelixChannelEntTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1HX_ent_dfa_0.15500'},
            'testName': 'avaHelixChannelEntTest',
        	'simType': 'ent',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1HX',
                'Release Area': ['Rel_Example', 'Rel_Two'],
                'Entrainment': 'Yes',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Release thickness [m]': [1, 1],
                'Entrainment thickness [m]': 0.3,
                'Initial mass [kg]': '34354424.00',
                'Final mass [kg]': '35018418.99',
                'Entrained mass [kg]': '663994.99',
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '141.5',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1HX'},
            'Entrainment area': {'type': 'columns', 'Entrainment area scenario': 'entrainment1HX'},
            'Resistance area': {'type': 'columns', 'Resistance area scenario': ''},
            'Test Info': {'type': 'text',
            'Test Info': 'This test uses a helix-shaped geometry with a channel with a channel.'}}

    elif testName ==  'avaHelixChannelEnt1mTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1HX_ent_dfa_0.15500'},
            'testName': 'avaHelixChannelEnt1mTest',
        	'simType': 'ent',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1HX',
                'Release Area': ['Rel_Example', 'Rel_Two'],
                'Entrainment': 'Yes',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Release thickness [m]': [1, 1],
                'Entrainment thickness [m]': 1.0,
                'Initial mass [kg]': '34354424.00',
                'Final mass [kg]': '36353187.29',
                'Entrained mass [kg]': '1998763.29',
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '139.1',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1HX'},
            'Entrainment area': {'type': 'columns', 'Entrainment area scenario': 'entrainment1HX', 'Entrainment Thickness': '1'},
            'Resistance area': {'type': 'columns', 'Resistance area scenario': ''},
            'Test Info': {'type': 'text',
            'Test Info': 'This test uses a helix-shaped geometry with a channel with a channel.'}}

    elif testName == 'avaParabolaResTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1PF_res_dfa_0.15500'},
        'testName': 'avaParabolaResTest',
        'simType': 'res',
        'Simulation Parameters': {
            'type': 'list',
            'Program version': 'macro',
            'Friction model': 'samosAT',
            'Release Area Scenario': 'release1PF',
            'Release Area': ['Rel_Example'],
            'Entrainment': 'No',
            'Resistance': 'Yes',
            'Mu': '0.15500',
            'Release thickness [m]': [1.0],
            'Density [kgm-3]': '200',
            'Initial mass [kg]': '20657132.08',
            'Final mass [kg]': '20657132.08',
            'Entrainment thickness [m]': 0.3,
            'Entrained mass [kg]': '0.00',
            'Stop criterion': '< 1.00 percent of PKE',
            'Avalanche run time [s]': '159.1',
            'run time [s]': ''},
        'Release area': {'type': 'columns', 'Release area scenario': 'release1PF'},
        'Test Info': {'type': 'text',
        'Test Info': 'This test runs on a parabolically sloping surface with a flat foreland.'}}

    elif testName == 'avaHockeyChannelEntTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1HS_ent_dfa_0.15500'},
        'testName': 'avaHockeyChannelEntTest',
        'simType': 'ent',
        'Simulation Parameters': {
            'type': 'list',
            'Program version': 'macro',
            'Friction model': 'samosAT',
            'Release Area Scenario': 'release1HS',
            'Release Area': ['Rel_Example'],
            'Entrainment': 'Yes',
            'Resistance': 'No',
            'Mu': '0.15500',
            'Density [kgm-3]': '200',
            'Release thickness [m]': [1.0],
            'Entrainment thickness [m]': 0.3,
            'Initial mass [kg]': ' 19939294.00',
            'Final mass [kg]': '20287572.97',
            'Entrained mass [kg]': '348278.96',
            'Stop criterion': '< 1.00 percent of PKE',
            'Avalanche run time [s]': '301.0',
            'run time [s]': ''},
        'Release area': {'type': 'columns', 'Release area scenario': 'release1HS'},
        'Entrainment area': {'type': 'columns', 'Entrainment area scenario': 'entrainment1HS'},
        'Resistance area': {'type': 'columns', 'Resistance area scenario': ''},
        'Test Info': {'type': 'text', 'Test Info': 'This test uses a hockey stick-shaped geometry, \
                    where a linearly sloping surface transitions smoothly into a flat foreland.'}}

    elif testName == 'avaHockeyChannelEntTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release2HS_ent_dfa_0.15500'},
            'testName': 'avaHockeyChannelEntTest',
        	'simType': 'ent',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release2HS',
                'Release Area': ['Rel_one', 'Rel_two'],
                'Entrainment': 'Yes',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Release thickness [m]': [1.0, 1.0],
                'Entrainment thickness [m]': 0.3,
                'Initial mass [kg]': '  24569688.02',
                'Final mass [kg]': '24569688.02',
                'Entrained mass [kg]': '0.00',
                'Stop criterion': 'end Time reached: 400.00',
                'Avalanche run time [s]': '400.00',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1HS'},
            'Entrainment area': {'type': 'columns', 'Entrainment area scenario': 'entrainment1HS'},
            'Resistance area': {'type': 'columns', 'Resistance area scenario': ''},
            'Test Info': {'type': 'text', 'Test Info': 'This test uses a hockey stick-shaped geometry, \
                     where a linearly sloping surface transitions smoothly into a flat foreland.'}}

    elif testName == 'avaHockeySmallNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1HS_null_dfa_0.15500'},
       	    'testName': 'avaHockeySmallNullTest',
       		'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1HS',
                'Release Area': ['Rel_Example'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Release thickness [m]': [1.0],
                'Density [kgm-3]': '200',
                'Initial mass [kg]': ' 10000000.05',
                'Final mass [kg]': ' 10000000.05',
                'Entrainment thickness [m]': 0.3,
                'Entrained mass [kg]': '0.0',
                'Stop criterion': 'end Time reached: 400.00',
                'Avalanche run time [s]': '400.00',
                'run time [s]': ''},
                'Release area': {'type': 'columns', 'Release area scenario': 'release1HS'},
                'Test Info': {'type': 'text', 'Test Info': 'This test uses a hockey stick-shaped geometry, \
                        where a linearly sloping surface transitions smoothly into a flat foreland. \
                        This geometry also includes a channel.'}}

    elif testName == 'avaInclinedPlaneEntresTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1IP_entres_dfa_0.15500'},
            'testName': 'avaInclinedPlaneEntresTest',
            'simType': 'entres',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1IP',
                'Release Area': ['Rel_Example'],
                'Entrainment': 'Yes',
                'Resistance': 'Yes',
                'Mu': '0.15500',
                'Release thickness [m]': [1.0],
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '20000000.10',
                'Final mass [kg]': '21735111.14',
                'Entrained mass [kg]': '1735111.04',
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': 'end Time reached: 400.00',
                'Avalanche run time [s]': '400.00',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1IP'},
            'Entrainment area': {'type': 'columns', 'Entrainment area scenario': 'entrainment1IP'},
            'Resistance area': {'type': 'columns', 'Resistance area scenario': ''},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs on a linearly sloping surface.'}}

    elif testName == 'avaAlrNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'relAlr_null_dfa_0.15500'},
            'testName': 'avaAlrNullTest',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'relAlr',
                'Release Area': ['AlR'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Release thickness [m]': [1.0],
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '10628076.99',
                'Final mass [kg]': '10628076.99',
                'Entrained mass [kg]': '0.00',
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '189.7',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'relAlr'},
            'Entrainment area': {'type': 'columns', 'Entrainment area scenario': ''},
            'Resistance area': {'type': 'columns', 'Resistance area scenario': ''},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs on a Alr DEM.'}}

    elif testName == 'avaKotNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'relKot_null_dfa_0.15500'},
            'testName': 'avaKotNullTest',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'relKot',
                'Release Area': ['KoT'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '4323417.01',
                'Final mass [kg]': '4323417.01',
                'Entrained mass [kg]': '0.00',
                'Release thickness [m]': [1.0],
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '113.9',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'relKot'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs the Kot test.'}}

    elif testName == 'avaMalNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'relMal1to3_null_dfa_0.15500'},
            'testName': 'avaMalNullTest',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'relMal1to3',
                'Release Area': ['MaL2', 'MaL3','MaL1'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '87760736.00',
                'Final mass [kg]': '87760736.00',
                'Entrained mass [kg]': '0.00',
                'Release thickness [m]': [1.0, 1.0, 1.0],
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '177',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'relMal1to3'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs the Mal test.'}}

    elif testName == 'avaWogNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'relWog_null_dfa_0.15500'},
            'testName': 'avaWogNullTest',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'relWog',
                'Release Area': ['WoG'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '33077667.99',
                'Final mass [kg]': '33077667.99',
                'Entrained mass [kg]': '0.00',
                'Release thickness [m]': [1.0],
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '164.9',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'relWog'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs the Wog test.'}}

    elif testName == 'avaGarNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'relGar_null_dfa_0.15500'},
            'testName': 'avaGarNullTest',
            'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'relGar',
                'Release Area': ['GaR1'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '12326455.00',
                'Final mass [kg]': '12326455.00',
                'Entrained mass [kg]': '0.00',
                'Release thickness [m]': [1.2],
                'Entrainment thickness [m]': 0.3,
                'Stop criterion':'< 1.00 percent of PKE',
                'Avalanche run time [s]': '123.8',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'relGar'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs the Gar test.'}}

    elif testName == 'avaGarNullTest2':
        avaDictName = {'simName': {'type': 'simName', 'name': 'relGar2_null_dfa_0.15500'},
            'testName': 'avaGarNullTest2',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'relGar2',
                'Release Area': ['GaR2'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '67027352.02',
                'Final mass [kg]': '67027352.02',
                'Entrained mass [kg]': '0.00',
                'Release thickness [m]': [1.5],
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '103.5',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'relGar2'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs the Gar test.'}}

    elif testName == 'avaGarNullTest6':
        avaDictName = {'simName': {'type': 'simName', 'name': 'relGar6_null_dfa_0.15500'},
            'testName': 'avaGarNullTest6',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'relGar6',
                'Release Area': ['GaR6'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '22112352.01',
                'Final mass [kg]': '22112352.01',
                'Entrained mass [kg]': '0.00',
                'Release thickness [m]': [1.0],
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '97',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'relGar6'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs the Gar test.'}}

    elif testName == 'avaHitNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'relHit_null_dfa_0.15500'},
            'testName': 'avaHitNullTest',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'relHit',
                'Release Area': ['HiT'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '53555964.00',
                'Final mass [kg]': '53555964.00',
                'Entrained mass [kg]': '0.00',
                'Release thickness [m]': [1.0],
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '155.8',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'relHit'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs the Hit test.'}}

    elif testName == 'avaPyramidNullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1PY_null_dfa_0.15500'},
            'testName': 'avaPyramidNullTest',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1PY',
                'Release Area': ['rel1'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Release thickness [m]': [1.0],
                'Entrainment thickness [m]': 0.3,
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1PY'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs the pyramid test.'}}

    elif testName == 'avaPyramid45NullTest':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1PY_null_dfa_0.15500'},
            'testName': 'avaPyramid45NullTest',
        	'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1PY',
                'Release Area': ['rel'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Release thickness [m]': [1.0],
                'Entrainment thickness [m]': 0.3,
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1PY'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs the rotation pyramid test.'}}

    elif testName == 'avaFlatPlaneNullTestPy':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1FP_null_dfa_f8fca36398'},
            'testName': 'avaFlatPlaneNullTestPy',
            'simType': 'null',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1FP',
                'Release Area': ['Rel_Example'],
                'Entrainment': 'No',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Release thickness [m]': [1.0],
                'Initial mass [kg]': '19500000.00',
                'Final mass [kg]': '19500000.00',
                'Entrained mass [kg]': '0.00',
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '17.80'},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1FP'},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs on a flat plane geometry.'}}

    elif testName == 'avaHelixChannelEntTestPy':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1HX_ent_dfa_f005e4e9c5'},
            'testName': 'avaHelixChannelEntTestPy',
            'simType': 'ent',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'com1DFAPy',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1HX',
                'Release Area': ['Rel_Example', 'Rel_Two'],
                'Entrainment': 'Yes',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Release thickness [m]': [1, 1],
                'Entrainment thickness [m]': 0.3,
                'Initial mass [kg]': '34264950.92',
                'Final mass [kg]': '34921704.69',
                'Entrained mass [kg]': '656753.77',
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '140.80',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1HX'},
            'Entrainment area': {'type': 'columns', 'Entrainment area scenario': 'entrainment1HX'},
            'Resistance area': {'type': 'columns', 'Resistance area scenario': ''},
            'Test Info': {'type': 'text',
                        'Test Info': 'This test uses a helix-shaped geometry with a channel with a channel.'}}

    elif testName == 'avaHockeyChannelEntTestPy':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1HS_ent_dfa_5afbc252c7'},
            'testName': 'avaHockeyChannelEntTestPy',
            'simType': 'ent',
            'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1HS',
                'Release Area': ['Rel_Example'],
                'Entrainment': 'Yes',
                'Resistance': 'No',
                'Mu': '0.15500',
                'Density [kgm-3]': '200',
                'Release thickness [m]': [1.0],
                'Entrained mass [kg]': '366651.77',
                'Entrainment thickness [m]': 0.3,
                'Initial mass [kg]': '19512767.70',
                'Final mass [kg]': '19879419.47',
                'Stop criterion': '< 1.00 percent of PKE',
                'Avalanche run time [s]': '309.40',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1HS'},
            'Entrainment area': {'type': 'columns', 'Entrainment area scenario': 'entrainment1HS'},
            'Resistance area': {'type': 'columns', 'Resistance area scenario': ''},
            'Test Info': {'type': 'text', 'Test Info': 'This test uses a hockey stick-shaped geometry, \
                     where a linearly sloping surface transitions smoothly into a flat foreland.'}}

    elif testName == 'avaInclinedPlaneEntresTestPy':
        avaDictName = {'simName': {'type': 'simName', 'name': 'release1IP_entres_dfa_eeaf249f5c'},
            'testName': 'avaInclinedPlaneEntresTestPy',
        	'simType': 'entres',
                'Simulation Parameters': {
                'type': 'list',
                'Program version': 'macro',
                'Friction model': 'samosAT',
                'Release Area Scenario': 'release1IP',
                'Release Area': ['Rel_Example'],
                'Entrainment': 'Yes',
                'Resistance': 'Yes',
                'Mu': '0.15500',
                'Release thickness [m]': [1.0],
                'Density [kgm-3]': '200',
                'Initial mass [kg]': '19570886.22',
                'Final mass [kg]': '21313398.02',
                'Entrained mass [kg]': '1742511.80',
                'Entrainment thickness [m]': 0.3,
                'Stop criterion': 'end Time reached: 400.00',
                'Avalanche run time [s]': '400.00',
                'run time [s]': ''},
            'Release area': {'type': 'columns', 'Release area scenario': 'release1IP'},
            'Entrainment area': {'type': 'columns', 'Entrainment area scenario': 'entrainment1IP'},
            'Resistance area': {'type': 'columns', 'Resistance area scenario': ''},
            'Test Info': {'type': 'text', 'Test Info': 'This test runs on a linearly sloping surface.'}}

    return avaDictName
